---
name: v.to.lines.py
description: Converts vector polygons or points to lines.
keywords: [ vector, geometry, area, line, point ]
---

# v.to.lines.py

Converts vector polygons or points to lines.

=== "Command line"

    **v.to.lines.py**
    **input**=*name*
    **output**=*name*
    [**method**=*string*]
    [**--overwrite**]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    v.to.lines.py input=name output=name
    ```

=== "Python (grass.script)"

    *grass.script.run_command*("***v.to.lines.py***",
        **input**,
        **output**,
        **method**=*"delaunay"*,
        **overwrite**=*False*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.run_command("v.to.lines.py", input="name", output="name")
    ```

## Parameters

=== "Command line"

    **input**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
    &nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
    **output**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
    **method**=*string*  
    &nbsp;&nbsp;&nbsp;&nbsp;Method used for point interpolation  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *delaunay*  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *delaunay*  
    **--overwrite**  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **input** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of input vector map  
    &nbsp;&nbsp;&nbsp;&nbsp;Or data source for direct OGR access  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, vector, *name*  
    **output** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name for output vector map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: output, vector, *name*  
    **method** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Method used for point interpolation  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *delaunay*  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *delaunay*  
    **overwrite**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allow output files to overwrite existing files  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

*v.to.lines* converts vector polygons (boundaries) to lines as well as
vector points to lines via triangulations.

## NOTES

*v.to.lines* is able to convert point data (via triangulation) and areas
to lines (via boundary to line conversion). This script is a wrapper
script to *v.category*, *v.delaunay*, and *v.edit*.

In order to convert an ordered list of coordinates (ASCII table with
x,y\[,z\] coordinates) into vector lines, use *v.in.lines*.

## EXAMPLES

The examples are for the North Carolina sample dataset:

### Area to line conversion

```sh
v.to.lines input=boundary_municp output=boundary_municp_lines
```

### Point to line conversion

```sh
v.to.lines input=geodetic_pts output=geodetic_pts_lines
```

## SEE ALSO

*[v.category](v.category.md), [v.delaunay](v.delaunay.md),
[v.edit](v.edit.md), [v.in.lines](v.in.lines.md),
[v.to.points](v.to.points.md), [v.type](v.type.md)*

## AUTHOR

Luca Delucchi, Fondazione Edmund Mach

## SOURCE CODE

Available at: [v.to.lines source code](https://github.com/OSGeo/grass/tree/main/scripts/v.to.lines)
([history](https://github.com/OSGeo/grass/commits/main/scripts/v.to.lines))  
Latest change: Monday May 19 11:52:48 2025 in commit [01f1bb4](https://github.com/OSGeo/grass/commit/01f1bb44b9df33803e83b9e3c52a28102000f6d8)
